@@ -48,27 +48,27 @@ after the standard collect action.  Aside from its own configuration, it
 requires the options and collect configuration sections in the standard Cedar
 Backup configuration file.
 
-The backup is done via the C{pg_dump} or C{pg_dumpall} commands included with
-the PostgreSQL product.  Output can be compressed using C{gzip} or C{bzip2}.
+The backup is done via the ``pg_dump`` or ``pg_dumpall`` commands included with
+the PostgreSQL product.  Output can be compressed using ``gzip`` or ``bzip2``.
 Administrators can configure the extension either to back up all databases or
 to back up only specific databases.  The extension assumes that the current
 user has passwordless access to the database since there is no easy way to pass
-a password to the C{pg_dump} client. This can be accomplished using appropriate
-voodoo in the C{pg_hda.conf} file.
+a password to the ``pg_dump`` client. This can be accomplished using appropriate
+voodoo in the ``pg_hda.conf`` file.
 
 Note that this code always produces a full backup.  There is currently no
 facility for making incremental backups.
 
-You should always make C{/etc/cback3.conf} unreadble to non-root users once you
+You should always make ``/etc/cback3.conf`` unreadble to non-root users once you
 place postgresql configuration into it, since postgresql configuration will
 contain information about available PostgreSQL databases and usernames.
 
-Use of this extension I{may} expose usernames in the process listing (via
-C{ps}) when the backup is running if the username is specified in the
+Use of this extension *may* expose usernames in the process listing (via
+``ps``) when the backup is running if the username is specified in the
 configuration.
 
-@author: Kenneth J. Pronovici <pronovic@ieee.org>
-@author: Antoine Beaupre <anarcat@koumbit.org>
+:author: Kenneth J. Pronovici <pronovic@ieee.org>
+:author: Antoine Beaupre <anarcat@koumbit.org>
 """
 
 ########################################################################
@@ -113,23 +113,22 @@ class PostgresqlConfig(object):
 
    The following restrictions exist on data in this class:
 
-      - The compress mode must be one of the values in L{VALID_COMPRESS_MODES}.
+      - The compress mode must be one of the values in :any:`VALID_COMPRESS_MODES`.
       - The 'all' flag must be 'Y' if no databases are defined.
       - The 'all' flag must be 'N' if any databases are defined.
       - Any values in the databases list must be strings.
 
-   @sort: __init__, __repr__, __str__, __cmp__, __eq__, __lt__, __gt__, user,
-         all, databases
    """
 
    def __init__(self, user=None, compressMode=None, all=None, databases=None):  # pylint: disable=W0622
       """
-      Constructor for the C{PostgresqlConfig} class.
+      Constructor for the ``PostgresqlConfig`` class.
 
-      @param user: User to execute backup as.
-      @param compressMode: Compress mode for backed-up files.
-      @param all: Indicates whether to back up all databases.
-      @param databases: List of databases to back up.
+      Args:
+         user: User to execute backup as
+         compressMode: Compress mode for backed-up files
+         all: Indicates whether to back up all databases
+         databases: List of databases to back up
       """
       self._user = None
       self._compressMode = None
@@ -167,8 +166,10 @@ class PostgresqlConfig(object):
    def __cmp__(self, other):
       """
       Original Python 2 comparison operator.
-      @param other: Other object to compare to.
-      @return: -1/0/1 depending on whether self is C{<}, C{=} or C{>} other.
+      Args:
+         other: Other object to compare to
+      Returns:
+          -1/0/1 depending on whether self is ``<``, ``=`` or ``>`` other
       """
       if other is None:
          return 1
@@ -212,8 +213,9 @@ class PostgresqlConfig(object):
    def _setCompressMode(self, value):
       """
       Property target used to set the compress mode.
-      If not C{None}, the mode must be one of the values in L{VALID_COMPRESS_MODES}.
-      @raise ValueError: If the value is not valid.
+      If not ``None``, the mode must be one of the values in :any:`VALID_COMPRESS_MODES`.
+      Raises:
+         ValueError: If the value is not valid
       """
       if value is not None:
          if value not in VALID_COMPRESS_MODES:
@@ -229,7 +231,7 @@ class PostgresqlConfig(object):
    def _setAll(self, value):
       """
       Property target used to set the 'all' flag.
-      No validations, but we normalize the value to C{True} or C{False}.
+      No validations, but we normalize the value to ``True`` or ``False``.
       """
       if value:
          self._all = True
@@ -245,8 +247,9 @@ class PostgresqlConfig(object):
    def _setDatabases(self, value):
       """
       Property target used to set the databases list.
-      Either the value must be C{None} or each element must be a string.
-      @raise ValueError: If the value is not a string.
+      Either the value must be ``None`` or each element must be a string.
+      Raises:
+         ValueError: If the value is not a string
       """
       if value is None:
          self._databases = None
@@ -288,48 +291,42 @@ class LocalConfig(object):
    Backup configuration object.  Instead, it just knows how to parse and emit
    PostgreSQL-specific configuration values.  Third parties who need to read and
    write configuration related to this extension should access it through the
-   constructor, C{validate} and C{addConfig} methods.
+   constructor, ``validate`` and ``addConfig`` methods.
 
-   @note: Lists within this class are "unordered" for equality comparisons.
+   *Note:* Lists within this class are "unordered" for equality comparisons.
 
-   @sort: __init__, __repr__, __str__, __cmp__, __eq__, __lt__, __gt__,
-         postgresql, validate, addConfig
    """
 
    def __init__(self, xmlData=None, xmlPath=None, validate=True):
       """
       Initializes a configuration object.
 
-      If you initialize the object without passing either C{xmlData} or
-      C{xmlPath} then configuration will be empty and will be invalid until it
+      If you initialize the object without passing either ``xmlData`` or
+      ``xmlPath`` then configuration will be empty and will be invalid until it
       is filled in properly.
 
       No reference to the original XML data or original path is saved off by
       this class.  Once the data has been parsed (successfully or not) this
       original information is discarded.
 
-      Unless the C{validate} argument is C{False}, the L{LocalConfig.validate}
+      Unless the ``validate`` argument is ``False``, the :any:`LocalConfig.validate`
       method will be called (with its default arguments) against configuration
       after successfully parsing any passed-in XML.  Keep in mind that even if
-      C{validate} is C{False}, it might not be possible to parse the passed-in
+      ``validate`` is ``False``, it might not be possible to parse the passed-in
       XML document if lower-level validations fail.
 
-      @note: It is strongly suggested that the C{validate} option always be set
-      to C{True} (the default) unless there is a specific need to read in
+      *Note:* It is strongly suggested that the ``validate`` option always be set
+      to ``True`` (the default) unless there is a specific need to read in
       invalid configuration from disk.
 
-      @param xmlData: XML data representing configuration.
-      @type xmlData: String data.
-
-      @param xmlPath: Path to an XML file on disk.
-      @type xmlPath: Absolute path to a file on disk.
-
-      @param validate: Validate the document after parsing it.
-      @type validate: Boolean true/false.
-
-      @raise ValueError: If both C{xmlData} and C{xmlPath} are passed-in.
-      @raise ValueError: If the XML data in C{xmlData} or C{xmlPath} cannot be parsed.
-      @raise ValueError: If the parsed configuration document is not valid.
+      Args:
+         xmlData (String data): XML data representing configuration
+         xmlPath (Absolute path to a file on disk): Path to an XML file on disk
+         validate (Boolean true/false): Validate the document after parsing it
+      Raises:
+         ValueError: If both ``xmlData`` and ``xmlPath`` are passed-in
+         ValueError: If the XML data in ``xmlData`` or ``xmlPath`` cannot be parsed
+         ValueError: If the parsed configuration document is not valid
       """
       self._postgresql = None
       self.postgresql = None
@@ -374,8 +371,10 @@ class LocalConfig(object):
       """
       Original Python 2 comparison operator.
       Lists within this class are "unordered" for equality comparisons.
-      @param other: Other object to compare to.
-      @return: -1/0/1 depending on whether self is C{<}, C{=} or C{>} other.
+      Args:
+         other: Other object to compare to
+      Returns:
+          -1/0/1 depending on whether self is ``<``, ``=`` or ``>`` other
       """
       if other is None:
          return 1
@@ -389,14 +388,15 @@ class LocalConfig(object):
    def _setPostgresql(self, value):
       """
       Property target used to set the postgresql configuration value.
-      If not C{None}, the value must be a C{PostgresqlConfig} object.
-      @raise ValueError: If the value is not a C{PostgresqlConfig}
+      If not ``None``, the value must be a ``PostgresqlConfig`` object.
+      Raises:
+         ValueError: If the value is not a ``PostgresqlConfig``
       """
       if value is None:
          self._postgresql = None
       else:
          if not isinstance(value, PostgresqlConfig):
-            raise ValueError("Value must be a C{PostgresqlConfig} object.")
+            raise ValueError("Value must be a ``PostgresqlConfig`` object.")
          self._postgresql = value
 
    def _getPostgresql(self):
@@ -405,17 +405,18 @@ class LocalConfig(object):
       """
       return self._postgresql
 
-   postgresql = property(_getPostgresql, _setPostgresql, None, "Postgresql configuration in terms of a C{PostgresqlConfig} object.")
+   postgresql = property(_getPostgresql, _setPostgresql, None, "Postgresql configuration in terms of a ``PostgresqlConfig`` object.")
 
    def validate(self):
       """
       Validates configuration represented by the object.
 
       The compress mode must be filled in.  Then, if the 'all' flag
-      I{is} set, no databases are allowed, and if the 'all' flag is
-      I{not} set, at least one database is required.
+      *is* set, no databases are allowed, and if the 'all' flag is
+      *not* set, at least one database is required.
 
-      @raise ValueError: If one of the validations fails.
+      Raises:
+         ValueError: If one of the validations fails
       """
       if self.postgresql is None:
          raise ValueError("PostgreSQL section is required.")
@@ -446,8 +447,9 @@ class LocalConfig(object):
 
          database       //cb_config/postgresql/database
 
-      @param xmlDom: DOM tree as from C{impl.createDocument()}.
-      @param parentNode: Parent that the section should be appended to.
+      Args:
+         xmlDom: DOM tree as from ``impl.createDocument()``
+         parentNode: Parent that the section should be appended to
       """
       if self.postgresql is not None:
          sectionNode = addContainerNode(xmlDom, parentNode, "postgresql")
@@ -462,13 +464,13 @@ class LocalConfig(object):
       """
       Internal method to parse an XML string into the object.
 
-      This method parses the XML document into a DOM tree (C{xmlDom}) and then
+      This method parses the XML document into a DOM tree (``xmlDom``) and then
       calls a static method to parse the postgresql configuration section.
 
-      @param xmlData: XML data to be parsed
-      @type xmlData: String data
-
-      @raise ValueError: If the XML cannot be successfully parsed.
+      Args:
+         xmlData (String data): XML data to be parsed
+      Raises:
+         ValueError: If the XML cannot be successfully parsed
       """
       (xmlDom, parentNode) = createInputDom(xmlData)
       self._postgresql = LocalConfig._parsePostgresql(parentNode)
@@ -489,10 +491,13 @@ class LocalConfig(object):
 
          databases      //cb_config/postgresql/database
 
-      @param parent: Parent node to search beneath.
+      Args:
+         parent: Parent node to search beneath
 
-      @return: C{PostgresqlConfig} object or C{None} if the section does not exist.
-      @raise ValueError: If some filled-in value is invalid.
+      Returns:
+          ``PostgresqlConfig`` object or ``None`` if the section does not exist
+      Raises:
+         ValueError: If some filled-in value is invalid
       """
       postgresql = None
       section = readFirstChild(parent, "postgresql")
@@ -518,17 +523,13 @@ def executeAction(configPath, options, config):
    """
    Executes the PostgreSQL backup action.
 
-   @param configPath: Path to configuration file on disk.
-   @type configPath: String representing a path on disk.
-
-   @param options: Program command-line options.
-   @type options: Options object.
-
-   @param config: Program configuration.
-   @type config: Config object.
-
-   @raise ValueError: Under many generic error conditions
-   @raise IOError: If a backup could not be written for some reason.
+   Args:
+      configPath (String representing a path on disk): Path to configuration file on disk
+      options (Options object): Program command-line options
+      config (Config object): Program configuration
+   Raises:
+      ValueError: Under many generic error conditions
+      IOError: If a backup could not be written for some reason
    """
    logger.debug("Executing PostgreSQL extended action.")
    if config.options is None or config.collect is None:
@@ -553,17 +554,20 @@ def _backupDatabase(targetDir, compressMode, user, backupUser, backupGroup, data
    This internal method wraps the public method and adds some functionality,
    like figuring out a filename, etc.
 
-   @param targetDir:  Directory into which backups should be written.
-   @param compressMode: Compress mode to be used for backed-up files.
-   @param user: User to use for connecting to the database.
-   @param backupUser: User to own resulting file.
-   @param backupGroup: Group to own resulting file.
-   @param database: Name of database, or C{None} for all databases.
+   Args:
+      targetDir:  Directory into which backups should be written
+      compressMode: Compress mode to be used for backed-up files
+      user: User to use for connecting to the database
+      backupUser: User to own resulting file
+      backupGroup: Group to own resulting file
+      database: Name of database, or ``None`` for all databases
 
-   @return: Name of the generated backup file.
+   Returns:
+       Name of the generated backup file
 
-   @raise ValueError: If some value is missing or invalid.
-   @raise IOError: If there is a problem executing the PostgreSQL dump.
+   Raises:
+      ValueError: If some value is missing or invalid
+      IOError: If there is a problem executing the PostgreSQL dump
    """
    (outputFile, filename) = _getOutputFile(targetDir, database, compressMode)
    with outputFile:
@@ -576,15 +580,17 @@ def _getOutputFile(targetDir, database, compressMode):
    """
    Opens the output file used for saving the PostgreSQL dump.
 
-   The filename is either C{"postgresqldump.txt"} or
-   C{"postgresqldump-<database>.txt"}.  The C{".gz"} or C{".bz2"} extension is
-   added if C{compress} is C{True}.
+   The filename is either ``"postgresqldump.txt"`` or
+   ``"postgresqldump-<database>.txt"``.  The ``".gz"`` or ``".bz2"`` extension is
+   added if ``compress`` is ``True``.
 
-   @param targetDir: Target directory to write file in.
-   @param database: Name of the database (if any)
-   @param compressMode: Compress mode to be used for backed-up files.
+   Args:
+      targetDir: Target directory to write file in
+      database: Name of the database (if any)
+      compressMode: Compress mode to be used for backed-up files
 
-   @return: Tuple of (Output file object, filename), file opened in binary mode for use with executeCommand()
+   Returns:
+       Tuple of (Output file object, filename), file opened in binary mode for use with executeCommand()
    """
    if database is None:
       filename = os.path.join(targetDir, "postgresqldump.txt")
@@ -612,27 +618,23 @@ def backupDatabase(user, backupFile, database=None):
 
    This function backs up either a named local PostgreSQL database or all local
    PostgreSQL databases, using the passed in user for connectivity.
-   This is I{always} a full backup.  There is no facility for incremental
+   This is *always* a full backup.  There is no facility for incremental
    backups.
 
    The backup data will be written into the passed-in back file.  Normally,
-   this would be an object as returned from C{open()}, but it is possible to
-   use something like a C{GzipFile} to write compressed output.  The caller is
+   this would be an object as returned from ``open``, but it is possible to
+   use something like a ``GzipFile`` to write compressed output.  The caller is
    responsible for closing the passed-in backup file.
 
-   @note: Typically, you would use the C{root} user to back up all databases.
+   *Note:* Typically, you would use the ``root`` user to back up all databases.
 
-   @param user: User to use for connecting to the database.
-   @type user: String representing PostgreSQL username.
-
-   @param backupFile: File use for writing backup.
-   @type backupFile: Python file object as from C{open()} or C{file()}.
-
-   @param database: Name of the database to be backed up.
-   @type database: String representing database name, or C{None} for all databases.
-
-   @raise ValueError: If some value is missing or invalid.
-   @raise IOError: If there is a problem executing the PostgreSQL dump.
+   Args:
+      user (String representing PostgreSQL username): User to use for connecting to the database
+      backupFile (Python file object as from ``open`` or ``file``): File use for writing backup
+      database (String representing database name, or ``None`` for all databases): Name of the database to be backed up
+   Raises:
+      ValueError: If some value is missing or invalid
+      IOError: If there is a problem executing the PostgreSQL dump
    """
    args = []
    if user is not None:
