@@ -43,7 +43,7 @@ command-line.  The only thing configuration would help with is the path
 resolver interface, and it doesn't seem worth it to require configuration just
 to get that.
 
-@author: Kenneth J. Pronovici <pronovic@ieee.org>
+:author: Kenneth J. Pronovici <pronovic@ieee.org>
 """
 
 ########################################################################
@@ -98,21 +98,21 @@ class Options(object):
    """
    Class representing command-line options for the cback3-amazons3-sync script.
 
-   The C{Options} class is a Python object representation of the command-line
+   The ``Options`` class is a Python object representation of the command-line
    options of the cback3-amazons3-sync script.
 
    The object representation is two-way: a command line string or a list of
-   command line arguments can be used to create an C{Options} object, and then
+   command line arguments can be used to create an ``Options`` object, and then
    changes to the object can be propogated back to a list of command-line
-   arguments or to a command-line string.  An C{Options} object can even be
+   arguments or to a command-line string.  An ``Options`` object can even be
    created from scratch programmatically (if you have a need for that).
 
-   There are two main levels of validation in the C{Options} class.  The first
+   There are two main levels of validation in the ``Options`` class.  The first
    is field-level validation.  Field-level validation comes into play when a
    given field in an object is assigned to or updated.  We use Python's
-   C{property} functionality to enforce specific validations on field values,
+   ``property`` functionality to enforce specific validations on field values,
    and in some places we even use customized list classes to enforce
-   validations on list members.  You should expect to catch a C{ValueError}
+   validations on list members.  You should expect to catch a ``ValueError``
    exception when making assignments to fields if you are programmatically
    filling an object.
 
@@ -124,15 +124,14 @@ class Options(object):
    throwing exceptions, etc.
 
    All of these post-completion validations are encapsulated in the
-   L{Options.validate} method.  This method can be called at any time by a
-   client, and will always be called immediately after creating a C{Options}
-   object from a command line and before exporting a C{Options} object back to
+   :any:`Options.validate` method.  This method can be called at any time by a
+   client, and will always be called immediately after creating a ``Options``
+   object from a command line and before exporting a ``Options`` object back to
    a command line.  This way, we get acceptable ease-of-use but we also don't
    accept or emit invalid command lines.
 
-   @note: Lists within this class are "unordered" for equality comparisons.
+   *Note:* Lists within this class are "unordered" for equality comparisons.
 
-   @sort: __init__, __repr__, __str__, __cmp__, __eq__, __lt__, __gt__
    """
 
    ##############
@@ -143,8 +142,8 @@ class Options(object):
       """
       Initializes an options object.
 
-      If you initialize the object without passing either C{argumentList} or
-      C{argumentString}, the object will be empty and will be invalid until it
+      If you initialize the object without passing either ``argumentList`` or
+      ``argumentString``, the object will be empty and will be invalid until it
       is filled in properly.
 
       No reference to the original arguments is saved off by this class.  Once
@@ -152,40 +151,36 @@ class Options(object):
       is discarded.
 
       The argument list is assumed to be a list of arguments, not including the
-      name of the command, something like C{sys.argv[1:]}.  If you pass
-      C{sys.argv} instead, things are not going to work.
+      name of the command, something like ``sys.argv[1:]``.  If you pass
+      ``sys.argv`` instead, things are not going to work.
 
       The argument string will be parsed into an argument list by the
-      L{util.splitCommandLine} function (see the documentation for that
+      :any:`util.splitCommandLine` function (see the documentation for that
       function for some important notes about its limitations).  There is an
-      assumption that the resulting list will be equivalent to C{sys.argv[1:]},
-      just like C{argumentList}.
+      assumption that the resulting list will be equivalent to ``sys.argv[1:]``,
+      just like ``argumentList``.
 
-      Unless the C{validate} argument is C{False}, the L{Options.validate}
+      Unless the ``validate`` argument is ``False``, the :any:`Options.validate`
       method will be called (with its default arguments) after successfully
       parsing any passed-in command line.  This validation ensures that
       appropriate actions, etc. have been specified.  Keep in mind that even if
-      C{validate} is C{False}, it might not be possible to parse the passed-in
+      ``validate`` is ``False``, it might not be possible to parse the passed-in
       command line, so an exception might still be raised.
 
-      @note: The command line format is specified by the L{_usage} function.
-      Call L{_usage} to see a usage statement for the cback3-amazons3-sync script.
+      *Note:* The command line format is specified by the ``_usage`` function.
+      Call ``_usage`` to see a usage statement for the cback3-amazons3-sync script.
 
-      @note: It is strongly suggested that the C{validate} option always be set
-      to C{True} (the default) unless there is a specific need to read in
+      *Note:* It is strongly suggested that the ``validate`` option always be set
+      to ``True`` (the default) unless there is a specific need to read in
       invalid command line arguments.
 
-      @param argumentList: Command line for a program.
-      @type argumentList: List of arguments, i.e. C{sys.argv}
-
-      @param argumentString: Command line for a program.
-      @type argumentString: String, i.e. "cback3-amazons3-sync --verbose stage store"
-
-      @param validate: Validate the command line after parsing it.
-      @type validate: Boolean true/false.
-
-      @raise getopt.GetoptError: If the command-line arguments could not be parsed.
-      @raise ValueError: If the command-line arguments are invalid.
+      Args:
+         argumentList (List of arguments, i.e. ``sys.argv``): Command line for a program
+         argumentString (String, i.e. "cback3-amazons3-sync --verbose stage store"): Command line for a program
+         validate (Boolean true/false): Validate the command line after parsing it
+      Raises:
+         getopt.GetoptError: If the command-line arguments could not be parsed
+         ValueError: If the command-line arguments are invalid
       """
       self._help = False
       self._version = False
@@ -249,8 +244,10 @@ class Options(object):
       """
       Original Python 2 comparison operator.
       Lists within this class are "unordered" for equality comparisons.
-      @param other: Other object to compare to.
-      @return: -1/0/1 depending on whether self is C{<}, C{=} or C{>} other.
+      Args:
+         other: Other object to compare to
+      Returns:
+          -1/0/1 depending on whether self is ``<``, ``=`` or ``>`` other
       """
       if other is None:
          return 1
@@ -339,7 +336,7 @@ class Options(object):
    def _setHelp(self, value):
       """
       Property target used to set the help flag.
-      No validations, but we normalize the value to C{True} or C{False}.
+      No validations, but we normalize the value to ``True`` or ``False``.
       """
       if value:
          self._help = True
@@ -355,7 +352,7 @@ class Options(object):
    def _setVersion(self, value):
       """
       Property target used to set the version flag.
-      No validations, but we normalize the value to C{True} or C{False}.
+      No validations, but we normalize the value to ``True`` or ``False``.
       """
       if value:
          self._version = True
@@ -371,7 +368,7 @@ class Options(object):
    def _setVerbose(self, value):
       """
       Property target used to set the verbose flag.
-      No validations, but we normalize the value to C{True} or C{False}.
+      No validations, but we normalize the value to ``True`` or ``False``.
       """
       if value:
          self._verbose = True
@@ -387,7 +384,7 @@ class Options(object):
    def _setQuiet(self, value):
       """
       Property target used to set the quiet flag.
-      No validations, but we normalize the value to C{True} or C{False}.
+      No validations, but we normalize the value to ``True`` or ``False``.
       """
       if value:
          self._quiet = True
@@ -403,7 +400,8 @@ class Options(object):
    def _setLogfile(self, value):
       """
       Property target used to set the logfile parameter.
-      @raise ValueError: If the value cannot be encoded properly.
+      Raises:
+         ValueError: If the value cannot be encoded properly
       """
       if value is not None:
          if len(value) < 1:
@@ -419,10 +417,11 @@ class Options(object):
    def _setOwner(self, value):
       """
       Property target used to set the owner parameter.
-      If not C{None}, the owner must be a C{(user,group)} tuple or list.
+      If not ``None``, the owner must be a ``(user,group)`` tuple or list.
       Strings (and inherited children of strings) are explicitly disallowed.
       The value will be normalized to a tuple.
-      @raise ValueError: If the value is not valid.
+      Raises:
+         ValueError: If the value is not valid
       """
       if value is None:
          self._owner = None
@@ -438,7 +437,7 @@ class Options(object):
    def _getOwner(self):
       """
       Property target used to get the owner parameter.
-      The parameter is a tuple of C{(user, group)}.
+      The parameter is a tuple of ``(user, group)``.
       """
       return self._owner
 
@@ -469,7 +468,7 @@ class Options(object):
    def _setOutput(self, value):
       """
       Property target used to set the output flag.
-      No validations, but we normalize the value to C{True} or C{False}.
+      No validations, but we normalize the value to ``True`` or ``False``.
       """
       if value:
          self._output = True
@@ -485,7 +484,7 @@ class Options(object):
    def _setDebug(self, value):
       """
       Property target used to set the debug flag.
-      No validations, but we normalize the value to C{True} or C{False}.
+      No validations, but we normalize the value to ``True`` or ``False``.
       """
       if value:
          self._debug = True
@@ -501,7 +500,7 @@ class Options(object):
    def _setStacktrace(self, value):
       """
       Property target used to set the stacktrace flag.
-      No validations, but we normalize the value to C{True} or C{False}.
+      No validations, but we normalize the value to ``True`` or ``False``.
       """
       if value:
          self._stacktrace = True
@@ -517,7 +516,7 @@ class Options(object):
    def _setDiagnostics(self, value):
       """
       Property target used to set the diagnostics flag.
-      No validations, but we normalize the value to C{True} or C{False}.
+      No validations, but we normalize the value to ``True`` or ``False``.
       """
       if value:
          self._diagnostics = True
@@ -533,7 +532,7 @@ class Options(object):
    def _setVerifyOnly(self, value):
       """
       Property target used to set the verifyOnly flag.
-      No validations, but we normalize the value to C{True} or C{False}.
+      No validations, but we normalize the value to ``True`` or ``False``.
       """
       if value:
          self._verifyOnly = True
@@ -549,7 +548,7 @@ class Options(object):
    def _setIgnoreWarnings(self, value):
       """
       Property target used to set the ignoreWarnings flag.
-      No validations, but we normalize the value to C{True} or C{False}.
+      No validations, but we normalize the value to ``True`` or ``False``.
       """
       if value:
          self._ignoreWarnings = True
@@ -592,19 +591,19 @@ class Options(object):
       """
       return self._s3BucketUrl
 
-   help = property(_getHelp, _setHelp, None, "Command-line help (C{-h,--help}) flag.")
-   version = property(_getVersion, _setVersion, None, "Command-line version (C{-V,--version}) flag.")
-   verbose = property(_getVerbose, _setVerbose, None, "Command-line verbose (C{-b,--verbose}) flag.")
-   quiet = property(_getQuiet, _setQuiet, None, "Command-line quiet (C{-q,--quiet}) flag.")
-   logfile = property(_getLogfile, _setLogfile, None, "Command-line logfile (C{-l,--logfile}) parameter.")
-   owner = property(_getOwner, _setOwner, None, "Command-line owner (C{-o,--owner}) parameter, as tuple C{(user,group)}.")
-   mode = property(_getMode, _setMode, None, "Command-line mode (C{-m,--mode}) parameter.")
-   output = property(_getOutput, _setOutput, None, "Command-line output (C{-O,--output}) flag.")
-   debug = property(_getDebug, _setDebug, None, "Command-line debug (C{-d,--debug}) flag.")
-   stacktrace = property(_getStacktrace, _setStacktrace, None, "Command-line stacktrace (C{-s,--stack}) flag.")
-   diagnostics = property(_getDiagnostics, _setDiagnostics, None, "Command-line diagnostics (C{-D,--diagnostics}) flag.")
-   verifyOnly = property(_getVerifyOnly, _setVerifyOnly, None, "Command-line verifyOnly (C{-v,--verifyOnly}) flag.")
-   ignoreWarnings = property(_getIgnoreWarnings, _setIgnoreWarnings, None, "Command-line ignoreWarnings (C{-w,--ignoreWarnings}) flag.")
+   help = property(_getHelp, _setHelp, None, "Command-line help (``-h,--help``) flag.")
+   version = property(_getVersion, _setVersion, None, "Command-line version (``-V,--version``) flag.")
+   verbose = property(_getVerbose, _setVerbose, None, "Command-line verbose (``-b,--verbose``) flag.")
+   quiet = property(_getQuiet, _setQuiet, None, "Command-line quiet (``-q,--quiet``) flag.")
+   logfile = property(_getLogfile, _setLogfile, None, "Command-line logfile (``-l,--logfile``) parameter.")
+   owner = property(_getOwner, _setOwner, None, "Command-line owner (``-o,--owner``) parameter, as tuple ``(user,group)``.")
+   mode = property(_getMode, _setMode, None, "Command-line mode (``-m,--mode``) parameter.")
+   output = property(_getOutput, _setOutput, None, "Command-line output (``-O,--output``) flag.")
+   debug = property(_getDebug, _setDebug, None, "Command-line debug (``-d,--debug``) flag.")
+   stacktrace = property(_getStacktrace, _setStacktrace, None, "Command-line stacktrace (``-s,--stack``) flag.")
+   diagnostics = property(_getDiagnostics, _setDiagnostics, None, "Command-line diagnostics (``-D,--diagnostics``) flag.")
+   verifyOnly = property(_getVerifyOnly, _setVerifyOnly, None, "Command-line verifyOnly (``-v,--verifyOnly``) flag.")
+   ignoreWarnings = property(_getIgnoreWarnings, _setIgnoreWarnings, None, "Command-line ignoreWarnings (``-w,--ignoreWarnings``) flag")
    sourceDir = property(_getSourceDir, _setSourceDir, None, "Command-line sourceDir, source of sync.")
    s3BucketUrl = property(_getS3BucketUrl, _setS3BucketUrl, None, "Command-line s3BucketUrl, target of sync.")
 
@@ -617,15 +616,16 @@ class Options(object):
       """
       Validates command-line options represented by the object.
 
-      Unless C{--help} or C{--version} are supplied, at least one action must
+      Unless ``--help`` or ``--version`` are supplied, at least one action must
       be specified.  Other validations (as for allowed values for particular
       options) will be taken care of at assignment time by the properties
       functionality.
 
-      @note: The command line format is specified by the L{_usage} function.
-      Call L{_usage} to see a usage statement for the cback3-amazons3-sync script.
+      *Note:* The command line format is specified by the ``_usage`` function.
+      Call ``_usage`` to see a usage statement for the cback3-amazons3-sync script.
 
-      @raise ValueError: If one of the validations fails.
+      Raises:
+         ValueError: If one of the validations fails
       """
       if not self.help and not self.version and not self.diagnostics:
          if self.sourceDir is None or self.s3BucketUrl is None:
@@ -640,23 +640,24 @@ class Options(object):
       argument list.   Besides that, the argument list is normalized to use the
       long option names (i.e. --version rather than -V).  The resulting list
       will be suitable for passing back to the constructor in the
-      C{argumentList} parameter.  Unlike L{buildArgumentString}, string
+      ``argumentList`` parameter.  Unlike :any:`buildArgumentString`, string
       arguments are not quoted here, because there is no need for it.
 
-      Unless the C{validate} parameter is C{False}, the L{Options.validate}
+      Unless the ``validate`` parameter is ``False``, the :any:`Options.validate`
       method will be called (with its default arguments) against the
       options before extracting the command line.  If the options are not valid,
       then an argument list will not be extracted.
 
-      @note: It is strongly suggested that the C{validate} option always be set
-      to C{True} (the default) unless there is a specific need to extract an
+      *Note:* It is strongly suggested that the ``validate`` option always be set
+      to ``True`` (the default) unless there is a specific need to extract an
       invalid command line.
 
-      @param validate: Validate the options before extracting the command line.
-      @type validate: Boolean true/false.
-
-      @return: List representation of command-line arguments.
-      @raise ValueError: If options within the object are invalid.
+      Args:
+         validate (Boolean true/false): Validate the options before extracting the command line
+      Returns:
+          List representation of command-line arguments
+      Raises:
+         ValueError: If options within the object are invalid
       """
       if validate:
          self.validate()
@@ -704,24 +705,25 @@ class Options(object):
       initialized with a command-line) is not preserved in this generated
       argument string.   Besides that, the argument string is normalized to use
       the long option names (i.e. --version rather than -V) and to quote all
-      string arguments with double quotes (C{"}).  The resulting string will be
-      suitable for passing back to the constructor in the C{argumentString}
+      string arguments with double quotes (``"``).  The resulting string will be
+      suitable for passing back to the constructor in the ``argumentString``
       parameter.
 
-      Unless the C{validate} parameter is C{False}, the L{Options.validate}
+      Unless the ``validate`` parameter is ``False``, the :any:`Options.validate`
       method will be called (with its default arguments) against the options
       before extracting the command line.  If the options are not valid, then
       an argument string will not be extracted.
 
-      @note: It is strongly suggested that the C{validate} option always be set
-      to C{True} (the default) unless there is a specific need to extract an
+      *Note:* It is strongly suggested that the ``validate`` option always be set
+      to ``True`` (the default) unless there is a specific need to extract an
       invalid command line.
 
-      @param validate: Validate the options before extracting the command line.
-      @type validate: Boolean true/false.
-
-      @return: String representation of command-line arguments.
-      @raise ValueError: If options within the object are invalid.
+      Args:
+         validate (Boolean true/false): Validate the options before extracting the command line
+      Returns:
+          String representation of command-line arguments
+      Raises:
+         ValueError: If options within the object are invalid
       """
       if validate:
          self.validate()
@@ -766,18 +768,18 @@ class Options(object):
       can be parsed and whether any values which exist are valid.  We don't do
       any validation as to whether required elements exist or whether elements
       exist in the proper combination (instead, that's the job of the
-      L{validate} method).
+      :any:`validate` method).
 
       For any of the options which supply parameters, if the option is
-      duplicated with long and short switches (i.e. C{-l} and a C{--logfile})
+      duplicated with long and short switches (i.e. ``-l`` and a ``--logfile``)
       then the long switch is used.  If the same option is duplicated with the
       same switch (long or short), then the last entry on the command line is
       used.
 
-      @param argumentList: List of arguments to a command.
-      @type argumentList: List of arguments to a command, i.e. C{sys.argv[1:]}
-
-      @raise ValueError: If the argument list cannot be successfully parsed.
+      Args:
+         argumentList (List of arguments to a command, i.e. ``sys.argv[1:]``): List of arguments to a command
+      Raises:
+         ValueError: If the argument list cannot be successfully parsed
       """
       switches = { }
       opts, remaining = getopt.getopt(argumentList, SHORT_SWITCHES, LONG_SWITCHES)
@@ -831,29 +833,30 @@ class Options(object):
 
 def cli():
    """
-   Implements the command-line interface for the C{cback3-amazons3-sync} script.
+   Implements the command-line interface for the ``cback3-amazons3-sync`` script.
 
    Essentially, this is the "main routine" for the cback3-amazons3-sync script.  It does
    all of the argument processing for the script, and then also implements the
    tool functionality.
 
-   This function looks pretty similiar to C{CedarBackup3.cli.cli()}.  It's not
+   This function looks pretty similiar to ``CedarBackup3.cli.cli()``.  It's not
    easy to refactor this code to make it reusable and also readable, so I've
    decided to just live with the duplication.
 
    A different error code is returned for each type of failure:
 
-      - C{1}: The Python interpreter version is < 3.4
-      - C{2}: Error processing command-line arguments
-      - C{3}: Error configuring logging
-      - C{5}: Backup was interrupted with a CTRL-C or similar
-      - C{6}: Error executing other parts of the script
+      - ``1``: The Python interpreter version is < 3.4
+      - ``2``: Error processing command-line arguments
+      - ``3``: Error configuring logging
+      - ``5``: Backup was interrupted with a CTRL-C or similar
+      - ``6``: Error executing other parts of the script
 
-   @note: This script uses print rather than logging to the INFO level, because
+   *Note:* This script uses print rather than logging to the INFO level, because
    it is interactive.  Underlying Cedar Backup functionality uses the logging
    mechanism exclusively.
 
-   @return: Error code as described above.
+   Returns:
+       Error code as described above
    """
    try:
       if list(map(int, [sys.version_info[0], sys.version_info[1]])) < [3, 4]:
@@ -924,8 +927,9 @@ def cli():
 def _usage(fd=sys.stderr):
    """
    Prints usage information for the cback3-amazons3-sync script.
-   @param fd: File descriptor used to print information.
-   @note: The C{fd} is used rather than C{print} to facilitate unit testing.
+   Args:
+      fd: File descriptor used to print information
+   *Note:* The ``fd`` is used rather than ``print`` to facilitate unit testing.
    """
    fd.write("\n")
    fd.write(" Usage: cback3-amazons3-sync [switches] sourceDir s3bucketUrl\n")
@@ -974,8 +978,9 @@ def _usage(fd=sys.stderr):
 def _version(fd=sys.stdout):
    """
    Prints version information for the cback3-amazons3-sync script.
-   @param fd: File descriptor used to print information.
-   @note: The C{fd} is used rather than C{print} to facilitate unit testing.
+   Args:
+      fd: File descriptor used to print information
+   *Note:* The ``fd`` is used rather than ``print`` to facilitate unit testing.
    """
    fd.write("\n")
    fd.write(" Cedar Backup Amazon S3 sync tool.\n")
@@ -997,8 +1002,9 @@ def _version(fd=sys.stdout):
 def _diagnostics(fd=sys.stdout):
    """
    Prints runtime diagnostics information.
-   @param fd: File descriptor used to print information.
-   @note: The C{fd} is used rather than C{print} to facilitate unit testing.
+   Args:
+      fd: File descriptor used to print information
+   *Note:* The ``fd`` is used rather than ``print`` to facilitate unit testing.
    """
    fd.write("\n")
    fd.write("Diagnostics:\n")
@@ -1015,10 +1021,10 @@ def _executeAction(options):
    """
    Implements the guts of the cback3-amazons3-sync tool.
 
-   @param options: Program command-line options.
-   @type options: Options object.
-
-   @raise Exception: Under many generic error conditions
+   Args:
+      options (Options object): Program command-line options
+   Raises:
+      Exception: Under many generic error conditions
    """
    sourceFiles = _buildSourceFiles(options.sourceDir)
    if not options.ignoreWarnings:
@@ -1035,8 +1041,10 @@ def _executeAction(options):
 def _buildSourceFiles(sourceDir):
    """
    Build a list of files in a source directory
-   @param sourceDir: Local source directory
-   @return: FilesystemList with contents of source directory
+   Args:
+      sourceDir: Local source directory
+   Returns:
+       FilesystemList with contents of source directory
    """
    if not os.path.isdir(sourceDir):
       raise ValueError("Source directory does not exist on disk.")
@@ -1053,8 +1061,9 @@ def _buildSourceFiles(sourceDir):
 def _checkSourceFiles(sourceDir, sourceFiles):
    """
    Check source files, trying to guess which ones will have encoding problems.
-   @param sourceDir: Local source directory
-   @param sourceDir: Local source directory
+   Args:
+      sourceDir: Local source directory
+      sourceDir: Local source directory
    @raises ValueError: If a problem file is found
    @see U{http://opensourcehacker.com/2011/09/16/fix-linux-filename-encodings-with-python/}
    @see U{http://serverfault.com/questions/82821/how-to-tell-the-language-encoding-of-a-filename-on-linux}
@@ -1107,8 +1116,9 @@ def _checkSourceFiles(sourceDir, sourceFiles):
 def _synchronizeBucket(sourceDir, s3BucketUrl):
    """
    Synchronize a local directory to an Amazon S3 bucket.
-   @param sourceDir: Local source directory
-   @param s3BucketUrl: Target S3 bucket URL
+   Args:
+      sourceDir: Local source directory
+      s3BucketUrl: Target S3 bucket URL
    """
    # Since at least early 2015, 'aws s3 sync' is always recursive and the
    # --recursive option is useless.  They eventually removed it and now using
@@ -1127,9 +1137,10 @@ def _synchronizeBucket(sourceDir, s3BucketUrl):
 def _verifyBucketContents(sourceDir, sourceFiles, s3BucketUrl):
    """
    Verify that a source directory is equivalent to an Amazon S3 bucket.
-   @param sourceDir: Local source directory
-   @param sourceFiles: Filesystem list containing contents of source directory
-   @param s3BucketUrl: Target S3 bucket URL
+   Args:
+      sourceDir: Local source directory
+      sourceFiles: Filesystem list containing contents of source directory
+      s3BucketUrl: Target S3 bucket URL
    """
    # As of this writing, the documentation for the S3 API that we're using
    # below says that up to 1000 elements at a time are returned, and that we
