@@ -25,7 +25,7 @@ Cedar Backup writers.
 This package consolidates all of the modules that implenent "image writer"
 functionality, including utilities and specific writer implementations.
 
-@author: Kenneth J. Pronovici <pronovic@ieee.org>
+:author: Kenneth J. Pronovici <pronovic@ieee.org>
 """
 
 
@@ -36,5 +36,9 @@ functionality, including utilities and specific writer implementations.
 # Using 'from CedarBackup3.writers import *' will just import the modules listed
 # in the __all__ variable.
 
+import CedarBackup3.writers.util
+import CedarBackup3.writers.cdwriter
+import CedarBackup3.writers.dvdwriter
+
 __all__ = [ 'util', 'cdwriter', 'dvdwriter', ]
 
