@@ -64,7 +64,7 @@ Naming Conventions
    functionality, and I prefer to avoid using overly descriptive (read: long)
    test names, as well.  Instead, I use lots of very small tests that each
    validate one specific thing.  These small tests are then named with an index
-   number, yielding something like C{testAddDir_001} or C{testValidate_010}.
+   number, yielding something like ``testAddDir_001`` or ``testValidate_010``.
    Each method has a docstring describing what it's supposed to accomplish.  I
    feel that this makes it easier to judge how important a given failure is,
    and also makes it somewhat easier to diagnose and fix individual problems.
@@ -128,7 +128,7 @@ class TestMediaDefinition(unittest.TestCase):
 
    def testConstructor_002(self):
       """
-      Test the constructor with the C{MEDIA_DVDPLUSR} media type.
+      Test the constructor with the ``MEDIA_DVDPLUSR`` media type.
       """
       media = MediaDefinition(MEDIA_DVDPLUSR)
       self.assertEqual(MEDIA_DVDPLUSR, media.mediaType)
@@ -137,7 +137,7 @@ class TestMediaDefinition(unittest.TestCase):
 
    def testConstructor_003(self):
       """
-      Test the constructor with the C{MEDIA_DVDPLUSRW} media type.
+      Test the constructor with the ``MEDIA_DVDPLUSRW`` media type.
       """
       media = MediaDefinition(MEDIA_DVDPLUSRW)
       self.assertEqual(MEDIA_DVDPLUSRW, media.mediaType)
